# Filestate Git

An extension for "filestate" package, which adds GIT management operations.

Version: 0.0.23

## Requirements

- Python >=3.6

## Dependencies

- pip-tools
- pydantic
- pytest
- requests
- wexample-filestate==0.0.30
- wexample-helpers-git==0.0.31
- wexample-helpers==0.0.30
- wexample-prompt==0.0.31

## Installation

```bash
pip install wexample-filestate-git
```

## Links

- Homepage: https://github.com/wexample/python-filestate-git

## License

MIT
## Credits

This package has been developed by [Wexample](https://wexample.com), a collection of tools and utilities to streamline development workflows.

Visit [wexample.com](https://wexample.com) to discover more tools and resources for efficient development.